/*
 *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
 *
 *  $Id: op.c,v 3.10 2004/09/12 08:01:52 shuu Exp shuu $
 *
 *  Can be freely distributed and used under the terms of the GNU GPL.
 */
#include	<stdlib.h>

#include	"murasaki.h"

mu_op_t mu_op = {
	flag: FLAG_BEEP,
	msg_level: MU_MSG_STD,
	device: generic,
	device_name: MU_ARG_GENERIC,
	command: MU_MURASAKI "." MU_ARG_GENERIC,
	mappath: {NULL,NULL,NULL,NULL},
	action: ACTION_NONE,
	config: NULL,
	sysfs: NULL,
	devpath: NULL,
	
	get_info: NULL,
	get_list: NULL,
	match_map: NULL,
	run: NULL,
	prepare: exec_device_script,
	end: exec_device_script,
};
